package org.rcisoft.integration.aep.Controller;

import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.integration.aep.service.IAepPushService;
import org.rcisoft.integration.jieLink.dto.JieLinkResultDto;
import org.rcisoft.integration.video.Service.IDaHuaVideoService;
import org.rcisoft.sys.doorreportdata.entity.DoorReportData;
import org.rcisoft.sys.doorreportdata.service.DoorReportDataService;
import org.rcisoft.sys.doorvideodevice.entity.DoorVideoDevice;
import org.rcisoft.sys.doorvideodevice.service.DoorVideoDeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/aep")
public class AepPushController {

    @Autowired
    private IAepPushService aepPushService;


    @Autowired
    private IDaHuaVideoService daHuaVideoService;

    @Autowired
    private DoorVideoDeviceService doorVideoDeviceService;

    @Autowired
    private DoorReportDataService doorReportDataService;

    /**
     * 门磁推送数据接口
     * @param data
     * @return
     */
    @ApiOperation(value="AEP平台集成", notes="门磁数据订阅")
    @PostMapping(value = "/pushData")
    public JieLinkResultDto pushData(@RequestBody JSONObject data) {
        JieLinkResultDto result = new JieLinkResultDto();
        result.setCode("200");
        result.setMsg("接收成功");
        /**
         * {
         *     "upPacketSN": -1,
         *     "deviceType": "",
         *     "productId": "15450893",
         *     "IMEI": "869907059730560",
         *     "deviceId": "611ace87bfa440c2b4378b804aad9200",
         *     "protocol": "lwm2m",
         *     "messageType": "dataReport",
         *     "payload": {
         *         "APPdata": "QUE1NTAxMDMwQTAxMDAwMDAwMDAwMEQwMEMwMDAwRUI="
         *     },
         *     "assocAssetId": "",
         *     "tenantId": "2000144885",
         *     "IMSI": "undefined",
         *     "topic": "v1/up/ad",
         *     "upDataSN": -1,
         *     "serviceId": "",
         *     "timestamp": 1670289730649
         * }
         * {
         *     "upPacketSN": -1,
         *     "deviceType": "",
         *     "productId": "15450893",
         *     "IMEI": "869907059730560",
         *     "deviceId": "611ace87bfa440c2b4378b804aad9200",
         *     "protocol": "lwm2m",
         *     "messageType": "dataReport",
         *     "payload": {
         *         "APPdata": "QUE1NTAxMDMwQTAwMDAwMDAwMDAwMEQwMEMwMDAwRUE="
         *     },
         *     "assocAssetId": "",
         *     "tenantId": "2000144885",
         *     "IMSI": "undefined",
         *     "topic": "v1/up/ad",
         *     "upDataSN": -1,
         *     "serviceId": "",
         *     "timestamp": 1670289731890
         * }
         */
        log.info(data.toJSONString());
        aepPushService.saveDoorSensorData(data);
        return result;
    }

    /**
     * 视频监控设备抓图①
     * @param dataId
     * @return
     */
    @ApiOperation(value="大华视频监控设备抓图①", notes="大华视频监控设备抓图")
    @GetMapping(value = "/grabVideoPic")
    public JieLinkResultDto grabVideoPic(String dataId) {
        JieLinkResultDto result = new JieLinkResultDto();
        boolean grabFlag = daHuaVideoService.grabVideoDevicePicData(dataId);
        if(grabFlag){
            result.setCode("200");
            result.setMsg("抓取成功");
        }else{
            result.setCode("-1");
            result.setMsg("抓取失败");
        }
        return result;
    }


    /**
     * 视频监控设备抓图②
     * @param dataId
     * @return
     */
    @ApiOperation(value="大华视频监控设备抓图②", notes="大华视频监控设备抓图")
    @GetMapping(value = "/grabVideoPicByDataId")
    public JieLinkResultDto grabVideoPicByDataId(String videoDeviceId,String dataId) {
        JieLinkResultDto result = new JieLinkResultDto();
        if(StringUtils.isNotBlank(videoDeviceId) && StringUtils.isNotBlank(dataId)){
            DoorVideoDevice videoDevice = doorVideoDeviceService.getDeviceInfoById(Long.parseLong(videoDeviceId));
            if(videoDevice==null){
                result.setCode("-1");
                result.setMsg("设备不存在");
                return result;
            }
            DoorReportData reportData = doorReportDataService.findById(Long.parseLong(dataId));
            if(reportData==null){
                result.setCode("-1");
                result.setMsg("对应数据不存在");
                return result;
            }
            boolean grabFlag = daHuaVideoService.grabVideoDevicePicData(videoDevice.getBusinessId().longValue(),reportData);
            if(grabFlag){
                result.setCode("200");
                result.setMsg("抓取成功");
            }else{
                result.setCode("-1");
                result.setMsg("抓取失败");
            }
        }else{
            result.setCode("-1");
            result.setMsg("参数缺失");
        }

        return result;
    }


}
