package org.rcisoft.integration.jieLink.Controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.integration.jieLink.dto.JieLinkDoorRecordDto;
import org.rcisoft.integration.jieLink.dto.JieLinkResultDto;
import org.rcisoft.integration.jieLink.service.IJieLinkService;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.rcisoft.sys.sysuser.service.SysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/jieLinkInter")
public class JieLinkInterController {

    @Autowired
    private IJieLinkService jieLinkService;

    @Autowired
    private SysUserService sysUserService;


    @CyOpeLogAnno(title = "jieLinkInter-捷顺道闸上传门禁记录", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="捷顺对接集成-门禁数据上传", notes="门禁数据上传")
    @PostMapping(value = "/doorrecord")
    public JieLinkResultDto addDoorrecord(@RequestBody JieLinkDoorRecordDto recodeDto) {
        log.info("=============================jieLink=====================================");
        log.info(JSONObject.toJSONString(recodeDto));
        log.info("=============================jieLink=====================================");
        JieLinkResultDto result = new JieLinkResultDto();
        if(recodeDto!=null && StringUtils.isNotBlank(recodeDto.getRecordId())){
            /**
             * 开始处理上传的门禁记录
             * 1、检查访客人员是否存在，不存在是否还需要新增
             * 2、检查设备系统内是否存在，不存在返回错误信息
             * 3、保存门禁记录信息，按照年划分
             */
            try{
                JieLinkResultDto jieLinkResultDto = jieLinkService.saveDoorRecordInfo(recodeDto);
                if(jieLinkResultDto!=null){
                    result = jieLinkResultDto;
                }else{
                    result.setCode("SYSTEM_ERROR");
                    result.setMsg("上传记录出现异常，请重新上传");
                }
            }catch (Exception ex){
                log.error(ex.getMessage(),ex);
                result.setCode("SYSTEM_ERROR");
                result.setMsg("上传记录出现异常，请重新上传");
            }
        }else{
            result.setCode("ILLEGAL_ARGUMENT");
            result.setMsg("参数缺失，请检查请求实体信息");
        }
        return result;
    }


    @ApiOperation(value="捷顺对接集成-同步设备信息", notes="同步设备信息")
    @GetMapping(value = "/syncDeviceData")
    public JieLinkResultDto syncDeviceData() {
        jieLinkService.syncDeviceInfo();
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("同步完成");
        result.setCode("0");
        return result;
    }

    @ApiOperation(value="捷顺对接集成-获取部门信息", notes="获取部门信息")
    @GetMapping(value = "/getDeptList")
    public JieLinkResultDto getDeptList() {
        jieLinkService.getDeptList();
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("同步完成");
        result.setCode("0");
        return result;
    }

    @ApiOperation(value="捷顺对接集成-删除用户", notes="删除用户")
    @GetMapping(value = "/delUser")
    public JieLinkResultDto delUser(String personId) {
        SysUser delUser = new SysUser();
        delUser.setPersonId(personId);
        jieLinkService.pushDelUserData(delUser);
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("删除完成");
        result.setCode("0");
        return result;
    }

    @ApiOperation(value="捷顺对接集成-加载所有用户信息", notes="加载所有用户信息")
    @GetMapping(value = "/loadAllUser")
    public JieLinkResultDto loadAllUser(Integer pageIndex) {
        String userListStr = jieLinkService.loadAllUserInfo(pageIndex);
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("删除完成");
        result.setCode("0");
        result.setData(userListStr);
        return result;
    }

    @ApiOperation(value="捷顺对接集成-根据用户ID获取二维码", notes="根据用户ID获取二维码")
    @GetMapping(value = "/loadUserQRCodePic")
    public JieLinkResultDto loadUserQRCodePic(String personId) {
        String qrCodeBase64Str = jieLinkService.pullVisitUserQrCode(personId);
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("加载成功");
        result.setCode("0");
        result.setData(qrCodeBase64Str);
        return result;
    }

    @ApiOperation(value="捷顺对接集成-根据用户ID开通门禁授权", notes="根据用户ID开通门禁授权")
    @GetMapping(value = "/openUserCertificateService")
    public JieLinkResultDto openUserCertificateService(String personId,Long userId) {
        boolean openStatus = jieLinkService.openCertificateServiceData(personId,userId);
        JieLinkResultDto result = new JieLinkResultDto();
        if(openStatus){
            result.setMsg("开通成功");
            result.setCode("0");
        }else{
            result.setMsg("开通失败");
            result.setCode("-1");
        }
        return result;
    }

    @ApiOperation(value="捷顺对接集成-根据用户获取凭证信息", notes="根据用户获取凭证信息")
    @GetMapping(value = "/loadUserCertificateData")
    public JieLinkResultDto loadUserCertificateData(Integer userId) {
        JieLinkResultDto result = new JieLinkResultDto();
        SysUser userInfo = sysUserService.getUserById(userId);
        if(userInfo!=null){
            JSONArray jsonArray = jieLinkService.loadUserCertificateData(userInfo);
            result.setMsg("获取成功");
            result.setCode("0");
            result.setData(jsonArray);
        }else{
            result.setMsg("用户信息错误");
            result.setCode("-1");
        }
        return result;
    }

    @ApiOperation(value="捷顺对接集成-根据用户删除凭证信息", notes="根据用户删除凭证信息")
    @GetMapping(value = "/delUserCertificateData")
    public JieLinkResultDto delUserCertificateData(Integer userId) {
        JieLinkResultDto result = new JieLinkResultDto();
        SysUser userInfo = sysUserService.getUserById(userId);
        if(userInfo!=null){
            boolean closeStatus = jieLinkService.closeCertificateServiceData(userInfo);
            if(closeStatus){
                result.setMsg("删除凭证成功");
                result.setCode("0");
            }else{
                result.setMsg("删除凭证失败");
                result.setCode("-1");
            }
        }else{
            result.setMsg("用户信息错误");
            result.setCode("-1");
        }
        return result;
    }



}
