package org.rcisoft.integration.jieLink.service.impl;


import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.RandomUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.integration.jieLink.common.SignUtils;
import org.rcisoft.integration.jieLink.dto.*;
import org.rcisoft.integration.jieLink.service.IZKTecoService;
import org.rcisoft.sys.devices.dao.DevicesRepository;
import org.rcisoft.sys.devices.entity.Devices;
import org.rcisoft.sys.devices.service.DevicesService;
import org.rcisoft.sys.messageinstance.dao.MessageInstanceRepository;
import org.rcisoft.sys.messageinstance.entity.MessageInstance;
import org.rcisoft.sys.messageinstance.service.impl.MessageInstanceServiceImpl;
import org.rcisoft.sys.sysuser.dao.SysDeptRepositorys;
import org.rcisoft.sys.sysuser.dao.SysDictDataRepositorys;
import org.rcisoft.sys.sysuser.dao.SysUserRepositorys;
import org.rcisoft.sys.sysuser.entity.DoorRecord;
import org.rcisoft.sys.sysuser.entity.SysDept;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.rcisoft.sys.sysuser.service.DoorRecordService;
import org.rcisoft.sys.sysuser.service.SysUserService;
import org.rcisoft.sys.sysusercard.service.SysUserCardService;
import org.rcisoft.sys.visit.dao.VisitInfomationRepository;
import org.rcisoft.sys.visit.dao.VisitUserRepository;
import org.rcisoft.sys.visit.entity.VisitInfoMation;
import org.rcisoft.sys.visit.entity.VisitUser;
import org.rcisoft.sys.visit.unit.TimeUtil;
import org.rcisoft.tencent.service.impl.CyWxMiniServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;

import java.io.IOException;
import java.math.BigInteger;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 万傲瑞达对接接口实现
 */
@Service
@Slf4j
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
public class ZKTecoServiceImpl implements IZKTecoService {

    /**
     * 服务地址
     */
    @Value("${zkteco.apiUrl}")
    private String zktecoUri;

    /**
     * apitoken
     */
    @Value("${zkteco.apiToken}")
    private String apiToken;

    /**
     * 西侧闸机
     */
    @Value("${zkteco.westGate}")
    private String westGate;

    /**
     * 东侧闸机
     */
    @Value("${zkteco.eastGate}")
    private String eastGate;


    @Autowired
    private RestTemplate restTemplate;

    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private DoorRecordService doorRecordService;

    @Autowired
    private VisitInfomationRepository visitInfomationRepository;

    @Autowired
    private VisitUserRepository visitUserRepository;

    @Autowired
    private DevicesService devicesService;

    @Autowired
    private SysDictDataRepositorys dictDataRepositorys;

    @Autowired
    private SysUserCardService sysUserCardService;

    @Autowired
    private SysUserRepositorys sysUserRepositorys;
    @Autowired
    private SysDeptRepositorys sysDeptRepositorys;
    @Autowired
    private MessageInstanceServiceImpl messageInstanceService;
    @Autowired
    private MessageInstanceRepository messageInstanceRepository;
    @Autowired
    private CyWxMiniServiceImpl cyWxMiniServiceImpl;
    @Autowired
    DevicesRepository devicesRepository;

    @Value("${global.path.base_discovery}")
    private String baseDiscovery;
    @Value("${global.path.base_upload_location}")
    private String baseUploadLocation;
    @Value("${wx.arriveTemplateId}")
    private String arriveTemplateId;
    @Value("${message.config}")
    private boolean message;


    /**
     * 推送新增用户对象到万傲服务中
     *
     * @param userData
     * @return
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public boolean pushAddUserData(SysUser userData) {
        String apiUri = "/api/person/add?access_token=";
        HttpHeaders headers = this.loadHeaderHandle();
        ZKTPersonDto pushData = this.convertUserBean(userData);
        HttpEntity<ZKTPersonDto> httpEntity = new HttpEntity<>(pushData, headers);
        StringBuffer uriAddr = new StringBuffer();
        uriAddr.append(zktecoUri).append(apiUri).append(apiToken);
        log.error("pushAddUserData接口传参信息：" + JSONObject.toJSONString(pushData));
        ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(uriAddr.toString(), httpEntity, JSONObject.class);
        try {
            if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                log.debug("pushAddUserData接口返回信息：" + responseEntity.getBody().toJSONString());
                JSONObject body = responseEntity.getBody();
                if (body.containsKey("code") && StringUtils.equals("0", body.getString("code"))) {
                    return true;
                } else {
                    log.error("pushAddUserData接口返回错误信息：" + body.getString("message"));
                    //请求返回结果错误啦
                    return false;
                }
            } else {
                //请求失败啦
                log.error("pushAddUserData接口请求失败");
                return false;
            }
        } catch (Exception ex) {
            log.error(ex.getMessage(), ex);
            return false;
        }
    }


    @Override
    public boolean pushDelUserData(SysUser userData) {
        if (userData != null && StringUtils.isNotBlank(userData.getPin())) {
            //删除人员权限
            boolean result = this.closeCertificateServiceData(userData);
            String apiUri = "/api/person/delete/";
            HttpHeaders headers = this.loadHeaderHandle();
            JSONObject paramMap = new JSONObject();
            HttpEntity<JSONObject> httpEntity = new HttpEntity<>(paramMap, headers);
            StringBuffer uriAddr = new StringBuffer();
            uriAddr.append(zktecoUri).append(apiUri).append(userData.getPin()).append("?access_token=").append(apiToken);
            log.error(uriAddr.toString());
            ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(uriAddr.toString(), httpEntity, JSONObject.class);
            try {
                if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                    log.debug("pushDelUserData接口返回信息：" + responseEntity.getBody().toJSONString());
                    ZKTResultDto<ZKTResultDto> resultData = JSONObject.toJavaObject(responseEntity.getBody(), ZKTResultDto.class);
                    if (StringUtils.equals(resultData.getCode(), "0")) {
                        //删除用户时，删除授权凭证
                        if (result) {
                            return true;
                        } else {
                            return false;
                        }
                    } else {
                        log.error("pushDelUserData接口返回错误信息：" + resultData.getMessage());
                        //请求返回结果错误啦
                        return false;
                    }
                } else {
                    //请求失败啦
                    log.error("pushDelUserData接口请求失败");
                    return false;
                }
            } catch (Exception ex) {
                log.error(ex.getMessage(), ex);
                return false;
            }
        } else {
            log.error("当前用户没有万傲系统的ID，无法更新");
            return true;
        }
    }


    /**
     * 删除人员权限
     *
     * @param userData
     * @return
     */
    @Override
    public boolean closeCertificateServiceData(SysUser userData) {
        //删除人员权限
        if (StringUtils.isNotBlank(userData.getPin())) {
            String apiUri = "/api/accLevel/deleteLevel";
            HttpHeaders headers = this.loadHeaderHandle();
            JSONObject paramMap = new JSONObject();
            HttpEntity<JSONObject> httpEntity = new HttpEntity<>(paramMap, headers);
            StringBuffer uriAddr = new StringBuffer();
            uriAddr.append(zktecoUri).append(apiUri).append("?pin=").append(userData.getPin())
                    .append("&levelIds=").append(westGate).append(",").append(eastGate)
                    .append("&access_token=").append(apiToken);
            ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(uriAddr.toString(), httpEntity, JSONObject.class);
            try {
                if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                    log.info("closeCertificateServiceData接口返回信息：" + responseEntity.getBody().toJSONString());
                    JSONObject body = responseEntity.getBody();
                    if (body.containsKey("code") && StringUtils.equals("0", body.getString("code"))) {
                        return true;
                    } else {
                        log.error("closeCertificateServiceData接口返回错误信息：" + body.getString("message"));
                        //请求返回结果错误啦
                        return false;
                    }
                } else {
                    //请求失败啦
                    log.error("closeCertificateServiceData接口请求失败");
                    return false;
                }
            } catch (Exception ex) {
                log.error(ex.getMessage(), ex);
                return false;
            }
        } else {
            //没有凭证可删除
            log.info("当前用户无万傲系统pin");
            return true;
        }
    }


    /**
     * 用户对象转换
     *
     * @param userData
     * @return
     */
    private ZKTPersonDto convertUserBean(SysUser userData) {
        ZKTPersonDto pushData = new ZKTPersonDto();
        pushData.setPin(userData.getPin());//人员编号
        pushData.setCarPlate(userData.getCarPlate());
        SysDept sysdept = sysDeptRepositorys.selectById(userData.getDeptId());
        if (sysdept != null && StringUtils.isNotBlank(sysdept.getZktCode()))
            pushData.setDeptCode(sysdept.getZktCode());
        pushData.setName(userData.getName());
        pushData.setGender(StringUtils.equals("0", userData.getSex()) ? "F" : StringUtils.equals("1", userData.getSex()) ? "M" : null);//性别
        //身份证处理
        if (StringUtils.isNotBlank(userData.getIdNumber())) {
            pushData.setCertNumber(userData.getIdNumber());//身份证
            pushData.setCertType("2");
        }
        pushData.setEmail(userData.getEmail());
        pushData.setDisabled(false);
        pushData.setMobilePhone(userData.getPhone());//必填
        //此处需要将头像信息转换成BASE64数据存储
        if (StringUtils.isNotBlank(userData.getFaceAddress())) {
            //读取文件将文件转换为base64字符串
            String path = userData.getFaceAddress().replaceAll(baseDiscovery, baseUploadLocation);
            log.error("path-----------" + path);
            String picBase64Str = encryptToBase64(path);
            if (StringUtils.isNotBlank(picBase64Str)) {
                pushData.setPersonPhoto(picBase64Str);
            }
            log.error("图片转换成功");
        }
        pushData.setAccLevelIds(westGate + "," + eastGate);
        //有效日期
        Date now = new Date();
        DateTime startTime = DateUtil.beginOfYear(now);
        //结束日期
        DateTime endTime = DateUtil.offset(startTime, DateField.YEAR, 10);
        pushData.setAccStartTime(DateUtil.format(startTime, "yyyy-MM-dd HH:mm:ss"));
        pushData.setAccEndTime(DateUtil.format(endTime, "yyyy-MM-dd HH:mm:ss"));
        return pushData;
    }


    public static void main(String[] args) {
//        SignDto signDto = new SignDto();
//        signDto.setAppId("app01");
//        signDto.setKey("01b470fd-67de-11ed-8c40-02004c4f4f50");
////        SignUtils.signData = appKeyInfo;
//        SignDto signData = SignUtils.getSignData(signDto);
//        HttpHeaders headers = new HttpHeaders();
//        headers.setContentType(MediaType.APPLICATION_JSON_UTF8);
//        headers.set("Accept", MediaType.APPLICATION_JSON_VALUE);
//        headers.set("appId", signData.getAppId());
//        headers.set("v", signData.getV());
//        headers.set("random", signData.getRandom());
//        headers.set("timestamp", signData.getTimestamp());
//        headers.set("sign", signData.getSign());
        String picBase64Str = encryptToBase64("C:\\Users\\DELL\\Pictures\\Camera Roll\\94efa5060651f9c0e4f4e345d0208625.jpeg");
        System.out.println(picBase64Str);
    }


    /**
     * 保存门禁访问记录
     *
     * @return {
     * "code": 0,
     * "message": "success",
     * "data": [
     * {
     * "id": "4028a8e481c83a9101865d01acd504d9",
     * "eventTime": "2023-02-17 09:33:48",
     * "pin": "80121489",
     * "name": "赵建宇",
     * "lastName": "",
     * "deptName": "总部研究院",
     * "areaName": "区域名称",
     * "cardNo": "",
     * "devSn": "CJ6V210960096",
     * "verifyModeName": "人脸",
     * "eventName": "正常验证开门",
     * "eventPointName": "东侧闸机4面部机-入",
     * "readerName": "192.168.40.89-1-出",
     * "accZone": null,
     * "devName": "东侧闸机4面部机-入",
     * "logId": 1322,
     * "eventNo": 0,
     * "eventLevel": 0,
     * "doorName": "东侧闸机4面部机-入"
     * }
     * ]
     * }
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    public boolean saveDoorRecordInfo(String startTime, String endTime) {
        String apiUri = "/api/transaction/list";
        int pageNo = 1;
        int pageSize = 1000;
        List<ZKTDoorRecordDto> list = new ArrayList<>();
        List<ZKTDoorRecordDto> data = new ArrayList<>();
        StringBuffer uriAddr = new StringBuffer();
        //获取门禁事件数据
        do {
            uriAddr = new StringBuffer();
            uriAddr.append(zktecoUri).append(apiUri).append("?pageNo=").append(pageNo).append("&pageSize=").append(pageSize)
                    .append("&startDate=").append(startTime).append("&endDate=").append(endTime)
                    .append("&access_token=").append(apiToken);
            ResponseEntity<JSONObject> responseEntity = restTemplate.getForEntity(uriAddr.toString(), JSONObject.class);
            try {
                if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                    log.error("门禁事件记录接口返回信息：" + responseEntity.getBody().toJSONString());
                    ZKTResultDto<String> resultData = JSONObject.toJavaObject(responseEntity.getBody(), ZKTResultDto.class);
                    if (StringUtils.equals(resultData.getCode(), "0")) {
                        String s = JSON.toJSONString(resultData.getData());
                        data = JSON.parseArray(s, ZKTDoorRecordDto.class);// 指定转换的类型
                        list.addAll(data);
                        pageNo += 1;
                    } else {
                        log.error("门禁事件记录接口返回错误信息：" + resultData.getMessage());
                        //请求返回结果错误啦
                        return false;
                    }
                } else {
                    //请求失败啦
                    log.error("门禁事件记录接口请求失败");
                    return false;
                }
            } catch (Exception ex) {
                log.error(ex.getMessage(), ex);
                return false;
            }
        } while (data.size() >= pageSize);
        List<DoorRecord> doorRecordList = new ArrayList<>();
        //整理入库
        for (ZKTDoorRecordDto zktDoorRecordDto : list) {
            SysUser sysUserData = null;
            if (StringUtils.isNotBlank(zktDoorRecordDto.getPin())) {
                String pin = zktDoorRecordDto.getPin();
                sysUserData = sysUserRepositorys.querySysUsersByPin(pin);
            } else {
                log.error("人员信息丢失，请检查参数pin:" + zktDoorRecordDto);
                continue;
            }
            String device = zktDoorRecordDto.getDevSn();
            Devices devices = null;
            if (StringUtils.isNotBlank(device)) {
//                if (StringUtils.isNotBlank(device.getDeviceGuid())) {
                Devices deviceInfo = devicesRepository.getDeviceInfoBySn(device);
                if (deviceInfo != null) {
                    devices = deviceInfo;
                } else {
                    //设备无了
                    log.error("设备未获取或关键信息错误，请检查参数:" + zktDoorRecordDto.getDevSn());
                    continue;
                }
            } else {
                //设备无了
                log.error("设备信息丢失，请检查参数:" + zktDoorRecordDto.getDevSn());
                continue;
            }
            DoorRecord record = new DoorRecord();
            record.setRecordId(zktDoorRecordDto.getId());
            record.setSource("2");
            if (sysUserData != null) {
                record.setUserId(sysUserData.getBusinessId());
                record.setPersonId(sysUserData.getPersonId());
                record.setPin(sysUserData.getPin());
                record.setMobile(sysUserData.getPhone());
                record.setTenementType(sysUserData.getUserType());
            } else {
                log.error("暂无访客逻辑:" + zktDoorRecordDto.getPin());
//                continue;
//                record.setPin(zktDoorRecordDto.getPin());
//                record.setPersonId(person.getPersonId());
//                record.setMobile(person.getMobile());
//                if (person.getTenementType() == 5 || person.getTenementType() == 7) {
//                    record.setTenementType("1");
//                } else {
//                    record.setTenementType("0");
//                }
                //
//            if (recordDto.getEventType().equals(103)) {
//                sysUserData = sysUserService.getUserByPersonId(zktDoorRecordDto.getPin());
//                if (sysUserData != null)
//                    record.setUserId(sysUserData.getBusinessId());
//            }
            }
            record.setRemark(zktDoorRecordDto.getVerifyModeName());
            record.setDeviceId(devices.getDeviceGuid());//需要根据设备补全
            record.setDeviceName(zktDoorRecordDto.getDevName());//需要根据设备补全
            //TODO 此处字段需要后续修改，需要根据业务调整
            record.setDeviceType(devices.getDeviceType() + "");//需要根据设备不全
            if (zktDoorRecordDto.getVerifyModeName().contains("人脸"))
                record.setCardType("169");
            record.setCardNo(zktDoorRecordDto.getCardNo());
            if (StringUtils.isNotBlank(zktDoorRecordDto.getEventTime())) {
                DateTime crossTime = DateUtil.parse(zktDoorRecordDto.getEventTime(), "yyyy-MM-dd HH:mm:ss");
                record.setCrossTime(crossTime.toJdkDate());
            } else {
                //触发时间无了
                log.error("闸机触发时间丢失,请检查参数:" + zktDoorRecordDto.getEventTime());
                continue;
            }
            record.setRecordType("1");
//            record.setEventType("104");
            record.setFlag("1");
            record.setDelFlag("0");
            record.setCreateBy(null);
            record.setCreateDate(new Date());
            record.setUpdateDate(record.getCreateDate());
//            doorRecordService.saveRecordData(record);
            doorRecordList.add(record);
//        updateTest(record, sysUserData);
        }
        if (!doorRecordList.isEmpty())
            doorRecordService.saveRecordDataList(doorRecordList);
        return true;
    }



    /**
     * 创建hander头信息
     *
     * @return
     */
    private HttpHeaders loadHeaderHandle() {
        //加载头部信息
//        if (SignUtils.signData != null) {
        SignDto signData = SignUtils.getSignData(SignUtils.signData);
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON_UTF8);
//        headers.set("Accept", MediaType.APPLICATION_JSON_VALUE);
//        headers.set("appId", signData.getAppId());
//        headers.set("v", signData.getV());
//        headers.set("random", signData.getRandom());
//        headers.set("timestamp", signData.getTimestamp());
//        headers.set("sign", signData.getSign());
        return headers;

//        }
    }

    /**
     * 将文件转换为base64字符串
     *
     * @param filePath
     * @return
     */
    public static String encryptToBase64(String filePath) {
        if (filePath == null) {
            return null;
        }
        try {
            byte[] b = Files.readAllBytes(Paths.get(filePath));
            return Base64.getEncoder().encodeToString(b);
        } catch (IOException e) {
            log.error("读取用户头像文件失败：" + e.getMessage(), e);
        }
        return null;
    }


    /**
     * 用户对象转换
     *
     * @param dept
     * @return
     */
    private ZKTDeptDto convertDeptBean(SysDept dept) {
        ZKTDeptDto pushData = new ZKTDeptDto();
        pushData.setCode(dept.getZktCode());
        pushData.setName(dept.getDeptName());
        SysDept parentDept = sysDeptRepositorys.selectById(dept.getParentId());
        if (parentDept != null)
            pushData.setParentCode(parentDept.getZktCode());
        return pushData;
    }


    /**
     * 推送新增用户对象到捷顺服务中
     *
     * @param sysDept
     * @return
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public boolean pushAddDeptData(SysDept sysDept) {
        String apiUri = "/api/department/add?access_token=";
        HttpHeaders headers = this.loadHeaderHandle();
        ZKTDeptDto pushData = this.convertDeptBean(sysDept);
        HttpEntity<ZKTDeptDto> httpEntity = new HttpEntity<>(pushData, headers);
        StringBuffer uriAddr = new StringBuffer();
        uriAddr.append(zktecoUri).append(apiUri).append(apiToken);
        ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(uriAddr.toString(), httpEntity, JSONObject.class);
        try {
            if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                log.info("pushAddDeptData接口返回信息：" + responseEntity.getBody().toJSONString());
                JSONObject body = responseEntity.getBody();
                if (body.containsKey("code") && StringUtils.equals("0", body.getString("code"))) {
                    return true;
                } else {
                    log.error("pushAddDeptData接口返回错误信息：" + body.getString("message"));
                    //请求返回结果错误啦
                    return false;
                }
            } else {
                //请求失败啦
                log.error("pushAddDeptData接口请求失败");
                return false;
            }
        } catch (Exception ex) {
            log.error(ex.getMessage(), ex);
            return false;
        }
    }


    @Override
    public boolean pushDelDeptData(SysDept sysDept) {
        if (sysDept != null && StringUtils.isNotBlank(sysDept.getZktCode())) {
            String apiUri = "/api/department/delete/";
            HttpHeaders headers = this.loadHeaderHandle();
//            if (headers != null) {
            JSONObject paramMap = new JSONObject();
//                paramMap.put("deptId", sysDept.getDepartmentId());
            HttpEntity<JSONObject> httpEntity = new HttpEntity<>(paramMap, headers);
            StringBuffer uriAddr = new StringBuffer();
            uriAddr.append(zktecoUri).append(apiUri).append(sysDept.getZktCode()).append("?access_token=").append(apiToken);
            ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(uriAddr.toString(), httpEntity, JSONObject.class);
            try {
                if (HttpStatus.OK.value() == responseEntity.getStatusCode().value()) {
                    log.debug("pushDelDeptData接口返回信息：" + responseEntity.getBody().toJSONString());
                    ZKTResultDto<ZKTResultDto> resultData = JSONObject.toJavaObject(responseEntity.getBody(), ZKTResultDto.class);
                    if (StringUtils.equals(resultData.getCode(), "0")) {
                        return true;
                    } else {
                        log.error("pushDelDeptData接口返回错误信息：" + resultData.getMessage());
                        //请求返回结果错误啦
                        return false;
                    }
                } else {
                    //请求失败啦
                    log.error("pushDelDeptData接口请求失败");
                    return false;
                }
            } catch (Exception ex) {
                log.error(ex.getMessage(), ex);
                return false;
            }
//            } else {
//                //认证信息获取失败
//                log.error("pushDelDeptData接口获取认证参数失败");
//                return false;
//            }
        } else {
            log.error("当前部門没有万傲系统的ID，无法删除");
            return true;
        }
    }
}
