package org.rcisoft.integration.video.Service.impl;

import lombok.extern.slf4j.Slf4j;
import org.rcisoft.core.util.CyDateUtil;
import org.rcisoft.integration.video.Service.IDaHuaVideoService;
import org.rcisoft.integration.video.common.VideoDeviceHandel;
import org.rcisoft.integration.video.config.CapturePicCallBack;
import org.rcisoft.integration.video.config.DaHuaVideoInitConfig;
import org.rcisoft.integration.video.lib.NetSDKLib;
import org.rcisoft.integration.video.utils.CapturePictureUtils;
import org.rcisoft.sys.doorreportdata.entity.DoorReportData;
import org.rcisoft.sys.doorvideodevice.entity.DoorVideoDevice;
import org.rcisoft.sys.doorvideodevice.service.DoorVideoDeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.util.Date;
import java.util.concurrent.TimeUnit;

import static java.lang.Thread.sleep;

/**
 * 大华视频监控设备服务
 */
@Service
@Slf4j
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
public class DahuaVideoServiceImpl implements IDaHuaVideoService {


    @Value("${global.path.base_upload_location}")
    private String baseUploadLocation;


    @Autowired
    private DoorVideoDeviceService doorVideoDeviceService;

    @Override
    public boolean grabVideoDevicePicData(String dataId) {
        /**
         * 先判断是否已经初始化,
         * 2、获取设备的配置信息
         * 3、判断设备是否已经登录
         * 4、未登录登录  一登录获取登录句柄
         * 5、调用抓图工具类
         * 6、回调写入数据
         */
        VideoDeviceHandel handel = null;

        if(!DaHuaVideoInitConfig.videoDeviceMap.containsKey(0L)){
            String deviceIp="192.168.42.225";
            int devicePort = 37777;
            String deviceAccount = "admin";
            String deviceSign = "admin123";
            boolean login = DaHuaVideoInitConfig.login(deviceIp, devicePort, deviceAccount, deviceSign);
            if(login){
                handel = DaHuaVideoInitConfig.videoDeviceMap.get(0l);
            }
        }else{
            handel = DaHuaVideoInitConfig.videoDeviceMap.get(0l);
            if(handel.isLoginStatus()){
                String deviceIp="192.168.42.225";
                int devicePort = 37777;
                String deviceAccount = "admin";
                String deviceSign = "admin123";
                boolean login = DaHuaVideoInitConfig.login(deviceIp, devicePort, deviceAccount, deviceSign);
                if(login){
                    handel = DaHuaVideoInitConfig.videoDeviceMap.get(0l);
                }
            }
        }
        if(handel == null ||!handel.isLoginStatus()){
            return false;
        }
        String basePath = baseUploadLocation;
        String savePicPath ="VIDEOPIC"+File.separator+ CyDateUtil.getSimpleDate("yyyyMMdd", new Date());
        DoorReportData data = new DoorReportData();
        data.setReportTime(new Date());
        CapturePicCallBack callBack = new CapturePicCallBack(basePath,savePicPath,data);
        CapturePictureUtils.setSnapRevCallBack(callBack,null);
        boolean picture = CapturePictureUtils.remoteCapturePicture(handel.getDeviceLoginHandle(), 0);
        return picture;
    }

    @Override
    public boolean grabVideoDevicePicData(Long videoDeviceId, DoorReportData reportData) {
        /**
         * 先判断是否已经初始化,
         * 2、获取设备的配置信息
         * 3、判断设备是否已经登录
         * 4、未登录登录  一登录获取登录句柄
         * 5、调用抓图工具类
         * 6、回调写入数据
         */
        VideoDeviceHandel handel = null;
        if(!DaHuaVideoInitConfig.videoDeviceMap.containsKey(videoDeviceId)){
            DoorVideoDevice videoDevice = doorVideoDeviceService.getDeviceInfoById(videoDeviceId);
            if(videoDevice!=null){
                String deviceIp=videoDevice.getDeviceIp();
                int devicePort = Integer.parseInt(videoDevice.getDevicePort());
                String deviceAccount = videoDevice.getDeviceAccount();
                String deviceSign = videoDevice.getDeviceSign();
                boolean login = DaHuaVideoInitConfig.login(videoDeviceId,deviceIp, devicePort, deviceAccount, deviceSign);
                if(login){
                    handel = DaHuaVideoInitConfig.videoDeviceMap.get(videoDeviceId);
                }
            }else{
                //设备未找到
                log.error("设备【"+videoDeviceId+"】 未找到");
                return false;
            }
        }else{
            handel = DaHuaVideoInitConfig.videoDeviceMap.get(videoDeviceId);
            if(!handel.isLoginStatus()){
                DoorVideoDevice videoDevice = doorVideoDeviceService.getDeviceInfoById(videoDeviceId);
                String deviceIp=videoDevice.getDeviceIp();
                int devicePort = Integer.parseInt(videoDevice.getDevicePort());
                String deviceAccount = videoDevice.getDeviceAccount();
                String deviceSign = videoDevice.getDeviceSign();
                boolean login = DaHuaVideoInitConfig.login(videoDeviceId,deviceIp, devicePort, deviceAccount, deviceSign);
                if(login){
                    handel = DaHuaVideoInitConfig.videoDeviceMap.get(videoDeviceId);
                }
            }
        }
        if(handel == null ||!handel.isLoginStatus()){
            log.error("设备【"+videoDeviceId+"】 未能注册成功或已掉线");
            return false;
        }
        String basePath = baseUploadLocation;
        String picSavePath ="VIDEOPIC"+File.separator+ CyDateUtil.getSimpleDate("yyyyMMdd", new Date());
        CapturePicCallBack callBack = new CapturePicCallBack(basePath,picSavePath,reportData);
        CapturePictureUtils.setSnapRevCallBack(callBack,null);
        boolean picture = CapturePictureUtils.timerCapturePicture(handel.getDeviceLoginHandle(), 0);
        NetSDKLib.LLong llong = handel.getDeviceLoginHandle();
        //异步
        new Thread(new Runnable(){
            @Override
            public void run() {
                try {
                    TimeUnit.SECONDS.sleep(3);
                    CapturePictureUtils.stopCapturePicture(llong, 0);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }).start();
        return picture;
    }
}
