package org.rcisoft.integration.video.config;


import lombok.extern.slf4j.Slf4j;
import org.rcisoft.integration.video.common.VideoDeviceHandel;
import org.rcisoft.integration.video.lib.NetSDKLib;
import org.rcisoft.integration.video.lib.NetSDKLib.LLong;

import java.io.File;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 大华视频监控设备SDK初始化配置
 */
@Slf4j
public class DaHuaVideoInitConfig {

    /**
     * 全局视频监控设备登录集合
     */
    public static ConcurrentHashMap<Long, VideoDeviceHandel> videoDeviceMap = new ConcurrentHashMap();

    /**
     * SDK核心
     */
    public static NetSDKLib netsdk 		= NetSDKLib.NETSDK_INSTANCE;
    public static NetSDKLib configsdk 	= NetSDKLib.CONFIG_INSTANCE;

    // 设备信息
    public static NetSDKLib.NET_DEVICEINFO_Ex m_stDeviceInfo = new NetSDKLib.NET_DEVICEINFO_Ex();



    /**
     * SDK初始化状态
     */
    private static boolean bInit    = false;

    /**
     * SDK日志输出状态
     */
    private static boolean bLogopen = false;

    /**
     * 初始化
     */
    public static boolean init(NetSDKLib.fDisConnect disConnect, NetSDKLib.fHaveReConnect haveReConnect) {
        bInit = netsdk.CLIENT_Init(disConnect, null);
        if(!bInit) {
            log.info("Initialize SDK failed");
            return false;
        }
        //打开日志，可选
        NetSDKLib.LOG_SET_PRINT_INFO setLog = new NetSDKLib.LOG_SET_PRINT_INFO();
        setLog.nPrintStrategy = 0;
        setLog.bSetFilePath = 1;
        setLog.bSetPrintStrategy = 1;
        bLogopen = netsdk.CLIENT_LogOpen(setLog);
        if(!bLogopen ) {
            log.error("Failed to open NetSDK log");
        }

        // 设置断线重连回调接口，设置过断线重连成功回调函数后，当设备出现断线情况，SDK内部会自动进行重连操作
        // 此操作为可选操作，但建议用户进行设置
        netsdk.CLIENT_SetAutoReconnect(haveReConnect, null);

        //设置登录超时时间和尝试次数，可选
        int waitTime = 5000; //登录请求响应超时时间设置为5S
        int tryTimes = 3;    //登录时尝试建立链接1次
        netsdk.CLIENT_SetConnectTime(waitTime, tryTimes);


        // 设置更多网络参数，NET_PARAM的nWaittime，nConnectTryNum成员与CLIENT_SetConnectTime
        // 接口设置的登录设备超时时间和尝试次数意义相同,可选
        NetSDKLib.NET_PARAM netParam = new NetSDKLib.NET_PARAM();
        netParam.nConnectTime = 10000;      // 登录时尝试建立链接的超时时间
        netParam.nGetConnInfoTime = 3000;   // 设置子连接的超时时间
        netParam.nGetDevInfoTime = 3000;//获取设备信息超时时间，为0默认1000ms
        netsdk.CLIENT_SetNetworkParam(netParam);
        return true;
    }


    /**
     * 清除环境
     */
    public static void cleanup() {
        if(bLogopen) {
            netsdk.CLIENT_LogClose();
        }

        if(bInit) {
            netsdk.CLIENT_Cleanup();
        }
    }



    /**
     * 登录设备
     */
    public static boolean login(String m_strIp, int m_nPort, String m_strUser, String m_strPassword) {
        //入参
        NetSDKLib.NET_IN_LOGIN_WITH_HIGHLEVEL_SECURITY pstInParam=new NetSDKLib.NET_IN_LOGIN_WITH_HIGHLEVEL_SECURITY();
        pstInParam.nPort=m_nPort;
        pstInParam.szIP=m_strIp.getBytes();
        pstInParam.szPassword=m_strPassword.getBytes();
        pstInParam.szUserName=m_strUser.getBytes();
        //出参
        NetSDKLib.NET_OUT_LOGIN_WITH_HIGHLEVEL_SECURITY pstOutParam=new NetSDKLib.NET_OUT_LOGIN_WITH_HIGHLEVEL_SECURITY();
        pstOutParam.stuDeviceInfo=m_stDeviceInfo;
        //m_hLoginHandle = netsdk.CLIENT_LoginEx2(m_strIp, m_nPort, m_strUser, m_strPassword, 0, null, m_stDeviceInfo, nError);
        // 登陆句柄
        LLong m_hLoginHandle=netsdk.CLIENT_LoginWithHighLevelSecurity(pstInParam, pstOutParam);
        if(m_hLoginHandle.longValue() == 0) {
            log.error("Login Device{} Port{}}Failed. %",m_strIp,m_nPort);
        } else {
            log.info("Login Success [ " + m_strIp + " ]");
        }
        boolean loginStatus =m_hLoginHandle.longValue() == 0? false:true;
        if(loginStatus){
            VideoDeviceHandel handel = new VideoDeviceHandel();
            handel.setDeviceLoginHandle(m_hLoginHandle);
            handel.setLoginStatus(true);
            videoDeviceMap.put(0L,handel);
        }
        return loginStatus;
    }

    /**
     * 登录设备
     */
    public static boolean login(Long deviceId,String m_strIp, int m_nPort, String m_strUser, String m_strPassword) {
        //入参
        NetSDKLib.NET_IN_LOGIN_WITH_HIGHLEVEL_SECURITY pstInParam=new NetSDKLib.NET_IN_LOGIN_WITH_HIGHLEVEL_SECURITY();
        pstInParam.nPort=m_nPort;
        pstInParam.szIP=m_strIp.getBytes();
        pstInParam.szPassword=m_strPassword.getBytes();
        pstInParam.szUserName=m_strUser.getBytes();
        //出参
        NetSDKLib.NET_OUT_LOGIN_WITH_HIGHLEVEL_SECURITY pstOutParam=new NetSDKLib.NET_OUT_LOGIN_WITH_HIGHLEVEL_SECURITY();
        pstOutParam.stuDeviceInfo=m_stDeviceInfo;
        //m_hLoginHandle = netsdk.CLIENT_LoginEx2(m_strIp, m_nPort, m_strUser, m_strPassword, 0, null, m_stDeviceInfo, nError);
        // 登陆句柄
        LLong m_hLoginHandle=netsdk.CLIENT_LoginWithHighLevelSecurity(pstInParam, pstOutParam);
        if(m_hLoginHandle.longValue() == 0) {
            log.error("Login Device{} Port{}}Failed. %",m_strIp,m_nPort);
        } else {
            log.info("Login Success [ " + m_strIp + " ]");
        }
        boolean loginStatus =m_hLoginHandle.longValue() == 0? false:true;
        if(loginStatus){
            VideoDeviceHandel handel = new VideoDeviceHandel();
            handel.setDeviceLoginHandle(m_hLoginHandle);
            handel.setLoginStatus(true);
            videoDeviceMap.put(deviceId,handel);
        }
        return loginStatus;
    }


    /**
     * 登出设备
     */
    public static boolean logout() {
        if(videoDeviceMap.containsKey(0L)){
            VideoDeviceHandel handel = videoDeviceMap.get(0L);
            if(handel.getDeviceLoginHandle()!=null && handel.isLoginStatus()){
                LLong m_hLoginHandle = handel.getDeviceLoginHandle();
                if(m_hLoginHandle.longValue() == 0) {
                    return false;
                }
                boolean bRet = netsdk.CLIENT_Logout(m_hLoginHandle);
                if(bRet) {
                    m_hLoginHandle.setValue(0);
                }
                return bRet;
            }else{
                return false;
            }
        }else{
            return false;
        }
    }

}
